@@ -1,5 +1,5 @@
 package Dancer2::Plugin::DebugDump;
-$Dancer2::Plugin::DebugDump::VERSION = '0.38';
+$Dancer2::Plugin::DebugDump::VERSION = '0.39';
 use strict;
 use warnings;
 
@@ -27,11 +27,11 @@ Dancer2::Plugin::DebugDump - Modified debug behavior to create multi-line output
 
 =head1 VERSION
 
-version 0.38
+version 0.39
 
 =head1 OVERVIEW
 
-[Dancer2::Plugin::DebugDump](http://search.cpan.org/perldoc?Dancer2%3A%3APlugin%3A%3ADebugDump), a software module written in the Perl programming language, is a simple plugin for the [Dancer2](http://perldancer.org/) web application framework. The target audience for this software is Dancer2 developers that use Dancer2's `debug` keyword during software development. It's purpose is to make the `debug` output in the log files or console easier to discern by formatting it across several lines.
+L<Dancer2::Plugin::DebugDump>, is a simple plugin for the [Dancer2](http://perldancer.org/) web application framework. The target audience for this software is Dancer2 developers that use Dancer2's `debug` keyword during software development. It's purpose is to make the `debug` output in the log files or console easier to discern by formatting it across several lines.
 
 =head1 SYNOPSIS
 
